Package: OrdMonReg
Type: Package
Title: Compute Least Squares Estimates of One Bounded or Two Ordered
        Isotonic Regression Curves
Version: 1.0.4
Date: 2026-04-26
Authors@R: 
    c(person(given = "Fadoua", family = "Balabdaoui", role = "aut", email = "fadoua.balabdaoui@stat.math.ethz.ch"),
      person(given = "Kaspar", family = "Rufibach", role = c("aut", "cre"), email = "kaspar.rufibach@gmail.com"),
      person(given = "Filippo", family = "Santambrogio", role = "aut", email = "santambrogio@math.univ-lyon1.fr"))
Description: We consider the problem of estimating two isotonic regression curves g1* and g2* under the constraint that they are ordered, i.e. g1* <= g2*. Given two sets of n data points y_1, ..., y_n and z_1, ..., z_n that are observed at (the same) deterministic design points x_1, ..., x_n, the estimates are obtained by minimizing the Least Squares criterion L(a, b) = sum_{i=1}^n (y_i - a_i)^2 w1(x_i) + sum_{i=1}^n (z_i - b_i)^2 w2(x_i) over the class of pairs of vectors (a, b) such that a and b are isotonic and a_i <= b_i for all i = 1, ..., n. We offer two different approaches to compute the estimates: a projected subgradient algorithm where the projection is calculated using a PAVA as well as Dykstra's cyclical projection algorithm.
License: GPL (>= 2)
URL: https://people.math.ethz.ch/~fadouab/,
        http://www.kasparrufibach.ch,
        https://math.univ-lyon1.fr/~santambrogio/
NeedsCompilation: no
Packaged: 2026-04-28 10:05:27 UTC; kaspa
Author: Fadoua Balabdaoui [aut],
  Kaspar Rufibach [aut, cre],
  Filippo Santambrogio [aut]
Maintainer: Kaspar Rufibach <kaspar.rufibach@gmail.com>
Depends: R (>= 2.10)
Repository: CRAN
Date/Publication: 2026-04-29 09:10:14 UTC
Built: R 4.4.3; ; 2026-05-01 13:09:09 UTC; unix
